@@ -1,10 +1,10 @@
 from datetime import datetime, date
 from typing import Optional
 
-from dapodik.base import dataclass
+import attr
 
 
-@dataclass(frozen=True, slots=True)
+@attr.dataclass(frozen=True, slots=True)
 class Kurikulum:
     kurikulum_id: int
     nama_kurikulum: str
