@@ -19,11 +19,14 @@ def cached(key: str, cache_prop: str = "cache"):
 def clean_response(data: str) -> str:
     data = data.replace("'success'", '"success"')
     data = data.replace("'message' : '", '"message" : "')
-    data = data.replace("', 'rows'", ':", :"rows:"')
+    if "rows" in data:
+        data = data.replace("', 'rows'", '", "rows"')
+    else:
+        data = data.replace("' }", '" }')
     return data
 
 
-def make_query(self, *args, **kwargs) -> dict:
+def make_query(*args, **kwargs) -> dict:
     query = dict()
     for key, val in dict(kwargs).items():
         if val is not None:
@@ -31,7 +34,7 @@ def make_query(self, *args, **kwargs) -> dict:
     return query
 
 
-def find_in(self, obj: List[T], is_this: Callable[[T], bool]) -> T:
+def find_in(obj: List[T], is_this: Callable[[T], bool]) -> T:
     for o in obj:
         if is_this(o):
             return o
